---
title: <span class="badge object-type-scalar"></span> DatetimeISONotToday
---
# <span class="badge object-type-scalar"></span> DatetimeISONotToday

Date & time: Datetime ISO (No date if today)

## Definition

```python
# Date & time: Datetime ISO (No date if today)
DatetimeISONotToday: typing.Literal["dateTimeAsIsoNoDateIfToday"] = "dateTimeAsIsoNoDateIfToday"
```
